@@ -97,8 +97,13 @@ class TaskWarrior(object):
         task = {"description": description}
         if tags != None:
             task['tags'] = tags
+
         task.update(kw)
 
+        # Only UNIX timestamps are currently supported.
+        if 'due' in kw:
+            task['due'] = str(task['due'])
+
         task['status'] = 'pending'
 
         # TODO -- check only valid keywords
